import React, { useState, useEffect } from "react"
import { isAdministrator } from "../../../services/auth"
import { navigate } from "gatsby"
import ProTable, { ProColumns } from "@ant-design/pro-table"
import { notification, Switch } from "antd"
//import JsonLanguages from "../../../settings/languages.json"
import { decodeUnicode } from "../../../utils/helper"

const columns: ProColumns[] = [
	{
		title: "#",
		dataIndex: "index",
		valueType: "indexBorder",
		width: 48,
		key: "key",
	},
	{
		title: "Title",
		dataIndex: "title",
	},
	{
		title: "Path",
		dataIndex: "path",
	},
	{
		title: "Enabled",
		dataIndex: "enabled",
		align: "right",
		render: (_, record) => (
			<Switch defaultChecked={record.enabled} size="small" />
		),
	},
	{
		title: "Default",
		dataIndex: "default",
		align: "right",
		render: (_, record) => (
			<Switch defaultChecked={record.default} size="small" />
		),
	},
]

const Languages = () => {
	const [dataSource, setDatasource] = useState([])
	const [sha, setSha] = useState("")

	const handleGitGet = async () => {
		try {
			const fetchGitApi = await fetch(
				`https://api.github.com/repos/${process.env.GATSBY_GITHUB_OWNER}/${process.env.GATSBY_GITHUB_REPO}/contents/src/@maad-dev/gatsby-theme-backend/settings/languages.json`,
				{
					method: "GET",
					headers: {
						authorization:
							"token " + process.env.GATSBY_GITHUB_PERSONAL_ACCESS_TOKEN,
						"Content-Type": "application/json; charset=UTF-8",
					},
				}
			)
				.then((response) => {
					return response.json()
				})
				.catch((error) => {
					console.log("Error ", error)
					notification["error"]({
						message: "Error code " + error.status,
						description: error.statusText,
						duration: 0,
					})
				})

			if (fetchGitApi) {
				return fetchGitApi
			} else {
				notification["info"]({
					message: "Empty Fetch",
					duration: 0,
				})
			}
		} catch (error) {
			console.log("Error handleGitGet ", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.statusText,
				duration: 0,
			})
		}
		return false
	}
	const handleGitUpdate = async (contentStr: string) => {
		try {
			const jsonStr = JSON.stringify(contentStr)
			const data = {
				message:
					"[skip ci] Update @maad-dev/gatsby-theme-backend/settings/languages.json from Modern backend.",
				content: btoa(jsonStr),
				sha: sha,
			}
			const fetchGitApi = await fetch(
				`https://api.github.com/repos/${process.env.GATSBY_GITHUB_OWNER}/${process.env.GATSBY_GITHUB_REPO}/contents/src/@maad-dev/gatsby-theme-backend/settings/primary-menu.json`,
				{
					method: "PUT",
					headers: {
						authorization:
							"token " + process.env.GATSBY_GITHUB_PERSONAL_ACCESS_TOKEN,
						"Content-Type": "application/json; charset=UTF-8",
					},
					body: JSON.stringify(data),
				}
			)
				.then((response) => {
					return response.json()
				})
				.catch((error) => {
					console.log("Error fetchGitApi PUT ", error)
					notification["error"]({
						message: "Error code " + error.status,
						description: error.statusText,
						duration: 0,
					})
				})

			if (fetchGitApi) {
				return true
			} else {
				notification["info"]({
					message: "Empty Fetch",
					duration: 0,
				})
			}
		} catch (error) {
			console.log("Error handleGitUpdate!", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.statusText,
				duration: 0,
			})
		}
		return false
	}

	const fetchDataSource = async (keyword: string) => {
		return await handleGitGet().then((getFile) => {
			if (getFile !== false) {
				const decodeContent = decodeUnicode(getFile.content)
				setDatasource(JSON.parse(decodeContent))
				setSha(getFile.sha)
			}
		})
	}

	useEffect(() => {
		if (!isAdministrator()) {
			notification["warning"]({
				message: "Warning!",
				description: "Your account is not allowed!",
			})
			navigate("/backend/dashboard")
		}
	}, [])

	return (
		<ProTable
			columns={columns}
			request={(params, sorter, filter) => {
				return Promise.resolve({
					data: dataSource,
					success: true,
				})
			}}
			rowKey="key"
			options={false}
			search={false}
			pagination={false}
		/>
	)
}

export default Languages
